@@ -1,8 +1,8 @@
 package Loverl;
 
-# ABSTRACT: Lover - A LÖVE2D game development command-line interface.
+# ABSTRACT: A LÖVE2D game development command-line interface.
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use v5.36;
 
@@ -25,11 +25,11 @@ __END__
 
 =head1 NAME
 
-Loverl - Lover - A LÖVE2D game development command-line interface.
+Loverl - A LÖVE2D game development command-line interface.
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -72,6 +72,18 @@ Loverl uses Perl version 5.36 or later.
     make
     make install
 
+=head2 Git
+
+    L<Git|https://git-scm.com/> should already be installed.
+
+=head2 LÖVE2D
+
+    L<LÖVE2D|https://love2d.org/> should already be installed.
+
+=head3 love PATH on Linux
+
+    The LINUX_LOVE_PATH environment variable should be set inorder to use the run command.
+
 =head1 AUTHOR
 
 Nobunaga <nobunaga@cpan.org>
