@@ -25,8 +25,13 @@ sub validate_args ( $self, $opt, $args ) {
 sub execute ( $self, $opt, $args ) {
     if ( -e "main.lua" ) {
         if ( -e "conf.lua" ) {
-            $zip->addTree( '.', '/' );
-            $zip->writeToFileNamed('LÖVE2DGame.love');
+            if ( -e "LÖVE2DGame.love" ) {
+                system("rm -rf LÖVE2DGame.love");
+                makeLoveFile();
+            }
+            else {
+                makeLoveFile();
+            }
         }
         else {
             croak("you are missing a conf.lua file");
@@ -38,6 +43,11 @@ sub execute ( $self, $opt, $args ) {
     print("test verbose") if $self->app->global_options->{verbose};
 }
 
+sub makeLoveFile() {
+    $zip->addTree( '.', '/' );
+    $zip->writeToFileNamed('LÖVE2DGame.love');
+}
+
 1;
 
 __END__
@@ -52,12 +62,18 @@ Loverl::Command::build - Builds the LÖVE2D project into a build directory
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
+    cd path/to/love2d/game/project/folder
+
     loverl build
 
+=head2 Requirements
+
+    Need main.lua and conf.lua to exist in order to use the command.
+
 =head1 DESCRIPTION
 
 Loverl's build command will build the LÖVE2D project into a build directory.
